package com.example.paypalintegrate.nativepaypal;

import android.util.Log;

import androidx.annotation.NonNull;

import com.paypal.checkout.PayPalCheckout;
import com.paypal.checkout.approve.Approval;
import com.paypal.checkout.approve.OnApprove;
import com.paypal.checkout.createorder.CreateOrder;
import com.paypal.checkout.createorder.CreateOrderActions;
import com.paypal.checkout.createorder.CurrencyCode;
import com.paypal.checkout.createorder.OrderIntent;
import com.paypal.checkout.createorder.UserAction;
import com.paypal.checkout.order.Amount;
import com.paypal.checkout.order.AppContext;
import com.paypal.checkout.order.CaptureOrderResult;
import com.paypal.checkout.order.OnCaptureComplete;
import com.paypal.checkout.order.Order;
import com.paypal.checkout.order.PurchaseUnit;

import java.util.ArrayList;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
/** NativepaypalPlugin */
public class NativepaypalPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  @Override
  public void onAttachedToEngine(FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "nativepaypal");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("startCheckout")) {
      startCheckout(call,result);
    } else {
      result.notImplemented();
    }
  }

  public void startCheckout(MethodCall call, MethodChannel.Result result){
    String clientID = call.argument("clientID");
    System.out.println(  PayPalCheckout.INSTANCE.isConfigSet());
    System.out.println("----------------");
    PayPalCheckout.start(
            new CreateOrder() {
              @Override
              public void create(CreateOrderActions createOrderActions) {
                ArrayList purchaseUnits = new ArrayList<>();
                purchaseUnits.add(
                        new PurchaseUnit.Builder()
                                .amount(
                                        new Amount.Builder()
                                                .currencyCode(CurrencyCode.BRL)
                                                .value("10.00")
                                                .build()
                                )
                                .build()
                );
                Order order = new Order(
                        OrderIntent.CAPTURE,
                        new AppContext.Builder()
                                .userAction(UserAction.PAY_NOW)
                                .build(),
                        purchaseUnits
                );
                createOrderActions.create(order, (CreateOrderActions.OnOrderCreated) null);
              }
            },
            new OnApprove() {
              @Override
              public void onApprove(Approval approval) {
                approval.getOrderActions().capture(new OnCaptureComplete() {
                  @Override
                  public void onCaptureComplete(CaptureOrderResult result) {
                    System.out.println("-------------------------aprovado");
                    Log.i("CaptureOrder", String.format("CaptureOrderResult: %s", result));
                  }
                });
              }
            }
    );

  }

  @Override
  public void onDetachedFromEngine( FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
